# tep

`tep`是**T**ry **E**asy **P**ytest的首字母缩写，是一款基于pytest测试框架的测试工具，集成了各种实用的第三方包和优秀的自动化测试设计思想，帮你快速实现自动化项目落地。

原创教程：

[https://dongfanger.gitee.io/blog/tep.html](https://dongfanger.gitee.io/blog/tep.html)

